{#
    basic/searchbox.html
    ~~~~~~~~~~~~~~~~~~~~

    Sphinx sidebar template: quick search box.

    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
{%- if pagename != "search" %}
<div id="searchbox" style="display: none">
  <h4>{{ _('Quick search') }}</h4>
    <form class="search" action="{{ pathto('search') }}" method="get">
      <input type="text" name="q" size="18" />
      <input type="submit" value="{{ _('Go') }}" />
      <input type="hidden" name="check_keywords" value="yes" />
      <input type="hidden" name="area" value="default" />
    </form>
    <p class="searchtip" style="font-size: 90%">
    {{ _('Enter search terms or a module, class or function name.') }}
    </p>
</div>
<!--<script type="text/javascript">$('#searchbox').show(0);</script>-->
{%- endif %}
